@@ -19,8 +19,8 @@ impl DiagnosticInfo {
         self.0[0] & 0b10000000 == 0
     }
 
-    /// Returns the unique ECU ID allocated by DCX for the specific ECU
-    pub fn get_dcx_ecu_id(&self) -> u8 {
+    /// Returns the unique ECU ID allocated by Daimler / MMC for the specific ECU
+    pub fn get_daimler_mmc_ecu_id(&self) -> u8 {
         self.0[0] & 0b01111111
     }
 
@@ -37,9 +37,9 @@ impl DiagnosticInfo {
     }
 }
 
-/// Identification structure read with [read_dcs_identification]
+/// Identification structure read with [read_daimler_identification]
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
-pub struct DcsEcuIdent {
+pub struct DaimlerEcuIdent {
     /// 10 digital part number
     pub part_number: String,
     /// Week of the year the ECU hardware was produced
@@ -66,9 +66,9 @@ pub struct DcsEcuIdent {
     pub ecu_production_day: u8,
 }
 
-/// Identification structure read with [read_dcx_mmc_identification]
+/// Identification structure read with [read_daimler_mmc_identification]
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
-pub struct DcxMmcEcuIdent {
+pub struct DaimlerMmcEcuIdent {
     /// Unknown
     pub ecu_origin: u8,
     /// Unique supplier ID (Who manufactured the ECU)
@@ -133,16 +133,16 @@ pub struct BlockIdentification {
     pub part_number: String,
 }
 
-/// Reads DCS ECU identification from ECU
-pub fn read_dcs_identification(
+/// Reads Daimler ECU identification from ECU
+pub fn read_daimler_identification(
     server: &mut Kwp2000DiagnosticServer,
-) -> DiagServerResult<DcsEcuIdent> {
+) -> DiagServerResult<DaimlerEcuIdent> {
     let res =
         server.execute_command_with_response(KWP2000Command::ReadECUIdentification, &[0x86])?;
     if res.len() != 18 {
         return Err(DiagError::InvalidResponseLength);
     }
-    Ok(DcsEcuIdent {
+    Ok(DaimlerEcuIdent {
         part_number: bcd_decode_slice(&res[2..7], None),
         ecu_hw_build_week: res[7],
         ecu_hw_build_year: res[8],
@@ -156,16 +156,16 @@ pub fn read_dcs_identification(
     })
 }
 
-/// Reads DCX/MMC ECU identification from ECU
-pub fn read_dcx_mmc_identification(
+/// Reads Daimler and MMC ECU identification from ECU
+pub fn read_daimler_mmc_identification(
     server: &mut Kwp2000DiagnosticServer,
-) -> DiagServerResult<DcxMmcEcuIdent> {
+) -> DiagServerResult<DaimlerMmcEcuIdent> {
     let res =
         server.execute_command_with_response(KWP2000Command::ReadECUIdentification, &[0x87])?;
     if res.len() != 22 {
         return Err(DiagError::InvalidResponseLength);
     }
-    Ok(DcxMmcEcuIdent {
+    Ok(DaimlerMmcEcuIdent {
         ecu_origin: res[2],
         supplier: res[3],
         diag_info: DiagnosticInfo([res[4], res[5]]),
@@ -321,4 +321,4 @@ pub fn read_ecu_boot_fingerprint(
     let mut res =
         server.execute_command_with_response(KWP2000Command::ReadECUIdentification, &[0x9F])?;
     decode_module_info(&mut res)
-}
+}
\ No newline at end of file
